@@ -1,13 +1,13 @@
 // Copyright 2020-2021 IOTA Stiftung
 // SPDX-License-Identifier: Apache-2.0
 
-use serde::Serialize;
+use serde::{Deserialize, Serialize};
 
 /// A marker trait to represent the data that can be included into `SuccessBody` and `ErrorBody`.
 pub trait BodyInner {}
 
 /// Describes the response body of a successful HTTP request.
-#[derive(Clone, Debug, Serialize)]
+#[derive(Clone, Debug, Serialize, Deserialize)]
 pub struct SuccessBody<T: BodyInner> {
     pub data: T,
 }
